@@ -1,9 +1,10 @@
 import { Message } from '@lumino/messaging';
 import { ISignal } from '@lumino/signaling';
 import { StackedPanel } from '@lumino/widgets';
-import { KernelUsageWidget } from './widget';
-import { jupyterIcon as icon } from '@jupyterlab/ui-components';
+import { LabIcon } from '@jupyterlab/ui-components';
 import { INotebookTracker, NotebookPanel } from '@jupyterlab/notebook';
+import { KernelUsageWidget } from './widget';
+import tachometer from '../style/tachometer.svg';
 
 const PANEL_CLASS = 'jp-kernelusage-view';
 
@@ -16,7 +17,10 @@ export class KernelUsagePanel extends StackedPanel {
     this.addClass(PANEL_CLASS);
     this.id = 'kernelusage-panel-id';
     this.title.caption = 'Kernel Usage';
-    this.title.icon = icon;
+    this.title.icon = new LabIcon({
+      name: 'jupyterlab-kernel-usage:icon',
+      svgstr: tachometer
+    });
     this.title.closable = true;
     const widget = new KernelUsageWidget({
       widgetAdded: props.widgetAdded,
